/* USER CODE BEGIN Header */
/**
  ******************************************************************************
  * @file           : led.h
  * @brief          : Header for led.c file.
  *                   This file contains the common defines of the application.
  ******************************************************************************
  * @attention    
  * Copyright 2024 SHANGHAI FUDAN MICROELECTRONICS GROUP CO., LTD.(FUDAN MICRO.)
  *        
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met: 
  *    
  * 1. Redistributions of source code must retain the above copyright notice, 
  *    this list of conditions and the following disclaimer.
  *    
  * 2. Redistributions in binary form must reproduce the above copyright notice,
  *    this list of conditions and the following disclaimer in the documentation
  *    and/or other materials provided with the distribution.
  *    
  * 3. Neither the name of the copyright holder nor the names of its contributors 
  *    may be used to endorse or promote products derived from this software without
  *    specific prior written permission.
  *    
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS"AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE   
  * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
  * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
  * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT   
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.    
  *
  ******************************************************************************
  */
/* USER CODE END Header */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __LED_H__
#define __LED_H__

#include "fm33ht0xxa_fl.h"

#define LED_GREEN_GPIO       GPIOB
#define LED_GREEN_PIN        FL_GPIO_PIN_6
  
#define LED_RED_GPIO         GPIOB
#define LED_RED_PIN          FL_GPIO_PIN_5

#define LED_BLUE_GPIO        GPIOB
#define LED_BLUE_PIN         FL_GPIO_PIN_4

#define LCD_BACKLIGHT_GPIO   GPIOB
#define LCD_BACKLIGHT_PIN    FL_GPIO_PIN_3


/*----------LED_GREEN---------------------------------------------------------*/
#define LED_GREEN_ON()   do{FL_GPIO_ResetOutputPin(LED_GREEN_GPIO, LED_GREEN_PIN);}while(0)
#define LED_GREEN_OFF()  do{FL_GPIO_SetOutputPin(LED_GREEN_GPIO, LED_GREEN_PIN);}while(0)
#define LED_GREEN_TOG()  do{FL_GPIO_ToggleOutputPin(LED_GREEN_GPIO, LED_GREEN_PIN);}while(0)
#define LED_GREEN_INIT() do{\
                             FL_GPIO_InitTypeDef    GPIO_InitStruct;\
                             GPIO_InitStruct.pin           = LED_GREEN_PIN;\
                             GPIO_InitStruct.mode          = FL_GPIO_MODE_OUTPUT;\
                             GPIO_InitStruct.outputType    = FL_GPIO_OUTPUT_PUSHPULL;\
                             GPIO_InitStruct.pull          = FL_GPIO_BOTH_DISABLE;\
                             GPIO_InitStruct.remapPin      = FL_GPIO_PINREMAP_FUNCTON0;\
                             GPIO_InitStruct.driveStrength = FL_GPIO_DRIVESTRENGTH_X3;\
                             (void)FL_GPIO_Init(LED_GREEN_GPIO, &GPIO_InitStruct );\
                         }while(0)

/*----------LED_RED-----------------------------------------------------------*/
#define LED_RED_ON()     do{FL_GPIO_ResetOutputPin(LED_RED_GPIO, LED_RED_PIN);}while(0)
#define LED_RED_OFF()    do{FL_GPIO_SetOutputPin(LED_RED_GPIO, LED_RED_PIN);}while(0)
#define LED_RED_TOG()    do{FL_GPIO_ToggleOutputPin(LED_RED_GPIO, LED_RED_PIN);}while(0)
#define LED_RED_INIT()   do{\
                             FL_GPIO_InitTypeDef    GPIO_InitStruct;\
                             GPIO_InitStruct.pin           = LED_RED_PIN;\
                             GPIO_InitStruct.mode          = FL_GPIO_MODE_OUTPUT;\
                             GPIO_InitStruct.outputType    = FL_GPIO_OUTPUT_PUSHPULL;\
                             GPIO_InitStruct.pull          = FL_GPIO_BOTH_DISABLE;\
                             GPIO_InitStruct.remapPin      = FL_GPIO_PINREMAP_FUNCTON0;\
                             GPIO_InitStruct.driveStrength = FL_GPIO_DRIVESTRENGTH_X3;\
                             (void)FL_GPIO_Init(LED_RED_GPIO, &GPIO_InitStruct );\
                         }while(0)
    
/*----------LED_BLUE----------------------------------------------------------*/
#define LED_BLUE_ON()    do{FL_GPIO_ResetOutputPin(LED_BLUE_GPIO, LED_BLUE_PIN);}while(0)
#define LED_BLUE_OFF()   do{FL_GPIO_SetOutputPin(LED_BLUE_GPIO, LED_BLUE_PIN);}while(0)
#define LED_BLUE_TOG()   do{FL_GPIO_ToggleOutputPin(LED_BLUE_GPIO, LED_BLUE_PIN);}while(0)
#define LED_BLUE_INIT()  do{\
                             FL_GPIO_InitTypeDef    GPIO_InitStruct;\
                             GPIO_InitStruct.pin           = LED_BLUE_PIN;\
                             GPIO_InitStruct.mode          = FL_GPIO_MODE_OUTPUT;\
                             GPIO_InitStruct.outputType    = FL_GPIO_OUTPUT_PUSHPULL;\
                             GPIO_InitStruct.pull          = FL_GPIO_BOTH_DISABLE;\
                             GPIO_InitStruct.remapPin      = FL_GPIO_PINREMAP_FUNCTON0;\
                             GPIO_InitStruct.driveStrength = FL_GPIO_DRIVESTRENGTH_X3;\
                             (void)FL_GPIO_Init(LED_BLUE_GPIO, &GPIO_InitStruct );\
                         }while(0)

/*----------LCD_BACKLIGHT-----------------------------------------------------*/
#define LED_LCD_BACKLIGHT_ON()    do{FL_GPIO_SetOutputPin(LCD_BACKLIGHT_GPIO, LCD_BACKLIGHT_PIN);}while(0)
#define LED_LCD_BACKLIGHT_OFF()   do{FL_GPIO_ResetOutputPin(LCD_BACKLIGHT_GPIO, LCD_BACKLIGHT_PIN);}while(0)
#define LED_LCD_BACKLIGHT_TOG()   do{FL_GPIO_ToggleOutputPin(LCD_BACKLIGHT_GPIO, LCD_BACKLIGHT_PIN);}while(0)
#define LED_LCD_BACKLIGHT_INIT()  do{\
                                     FL_GPIO_InitTypeDef    GPIO_InitStruct;\
                                     GPIO_InitStruct.pin           = LCD_BACKLIGHT_PIN;\
                                     GPIO_InitStruct.mode          = FL_GPIO_MODE_OUTPUT;\
                                     GPIO_InitStruct.outputType    = FL_GPIO_OUTPUT_PUSHPULL;\
                                     GPIO_InitStruct.pull          = FL_GPIO_BOTH_DISABLE;\
                                     GPIO_InitStruct.remapPin      = FL_GPIO_PINREMAP_FUNCTON0;\
                                     GPIO_InitStruct.driveStrength = FL_GPIO_DRIVESTRENGTH_X3;\
                                     (void)FL_GPIO_Init(LCD_BACKLIGHT_GPIO, &GPIO_InitStruct );\
                                  }while(0)


/* RED */
/* GREEN */
/* BLUE */
/* LCD_BACKLIGHT */
#define LED_ON(X)        do{LED_##X##_ON();  LED_##X##_INIT();}while(0)
#define LED_OFF(X)       do{LED_##X##_OFF(); LED_##X##_INIT();}while(0)
#define LED_TOG(X)       do{LED_##X##_TOG(); LED_##X##_INIT();}while(0)
#define LED_TOG_FUN(COLOUR, TIMES, CALL_BACK)\
                         do{uint32_t i = (TIMES);\
                            do{LED_ON(COLOUR);(CALL_BACK);LED_OFF(COLOUR);(CALL_BACK);}while(--i);\
                           }while(0)
                             
#endif

