/* USER CODE BEGIN Header */
/**
  ******************************************************************************
  * @file           : pll.h
  * @brief          : Header for pll.c file.
  *                   This file contains the common defines of the application.
  ******************************************************************************
  * @attention    
  * Copyright 2024 SHANGHAI FUDAN MICROELECTRONICS GROUP CO., LTD.(FUDAN MICRO.)
  *        
  * Redistribution and use in source and binary forms, with or without modification,
  * are permitted provided that the following conditions are met: 
  *    
  * 1. Redistributions of source code must retain the above copyright notice, 
  *    this list of conditions and the following disclaimer.
  *    
  * 2. Redistributions in binary form must reproduce the above copyright notice,
  *    this list of conditions and the following disclaimer in the documentation
  *    and/or other materials provided with the distribution.
  *    
  * 3. Neither the name of the copyright holder nor the names of its contributors 
  *    may be used to endorse or promote products derived from this software without
  *    specific prior written permission.
  *    
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS"AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE   
  * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
  * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
  * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT   
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.    
  *
  ******************************************************************************
  */
/* USER CODE END Header */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __PLL_H__
#define __PLL_H__

/* Includes ------------------------------------------------------------------*/
#include "fm33ht0xxa_fl.h"
#include <stdio.h>

#define SYSCLK_HOLD_STOP_UNTILE_RESUMED    0U  /* XTHF停振或PLL失锁导致系统时钟源发生故障时，
                                                  系统时钟保持停止，直至时钟源(XTHF/PLL)恢复 */
                                                  
#define SYSCLK_SWITCH_TO_BACKUP_CLOCK      1U  /* XTHF停振或PLL失锁导致系统时钟源发生故障时，
                                                  系统时钟切换到备份时钟(RCHF)，
                                                  待时钟源(XTHF/PLL)恢复后再切回实际时钟 */

#define SYSCLK_FAULT_HANDING_MODE  SYSCLK_SWITCH_TO_BACKUP_CLOCK  /* 用户选择 
                                                                     XTHF停振或PLL失锁导致系统时钟源发生故障时,
                                                                     用户选择系统时钟的处理模式 */

typedef enum
{
    SYSCLK_NORMAL = 0x00000000,
    SYSCLK_ERROR  = 0x55AAAA55,
}SYSCLK_STATE;

extern volatile uint32_t SYSCLKSELErrorState;
extern volatile SYSCLK_STATE SYSCLKState;

extern const FL_CMU_RCHF_InitTypeDef CMU_RCHF_Init_Data;
extern const FL_CMU_XTHF_InitTypeDef CMU_XTHF_Init_Data;
extern const FL_CMU_PLL_InitTypeDef CMU_PLL_Init_Data;

extern void SwtichToSenondarySystemClock(const FL_CMU_RCHF_InitTypeDef *rchf,
                                         const FL_CMU_PLL_InitTypeDef  *pll);

extern void SwtichToMainSystemClock(const FL_CMU_RCHF_InitTypeDef *rchf,
                                    const FL_CMU_XTHF_InitTypeDef *xthf,
                                    const FL_CMU_PLL_InitTypeDef  *pll);
                                    
extern void RCC_PLL_ConfigDomain_SYS(uint32_t Source, uint32_t PLL_R, uint32_t PLL_DB);
                                    
extern void XTHFInit(const FL_CMU_XTHF_InitTypeDef *init);
                                    
extern uint32_t SelXTHFToPLL(const FL_CMU_XTHF_InitTypeDef *xthfInit, 
                             const FL_CMU_PLL_InitTypeDef  *pllInit);

#endif  /* __PLL_H__ */

/************************ (C) COPYRIGHT FMSH *****END OF FILE****/
